/******************************************************************************
* File Name: main_cm4.c
*
* Version: 1.0
*
* Description: This example shows how to re-direct the printf function to 
* use UART API to send data to external terminal.
*
* Related Document: CE223001_PSoC6MCU_UART_printf.pdf
*
* Hardware Dependency: CY8CKIT-062-BLE PSoC 6 BLE Pioneer kit
*
******************************************************************************
* Copyright (2018), Cypress Semiconductor Corporation.
******************************************************************************
* This software, including source code, documentation and related materials
* ("Software") is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress source code and derivative works for the sole purpose of creating 
* custom software in support of licensee product, such licensee product to be
* used only in conjunction with Cypress's integrated circuit as specified in the
* applicable agreement. Any reproduction, modification, translation, compilation,
* or representation of this Software except as specified above is prohibited 
* without the express written permission of Cypress.
* 
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, 
* EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes to the Software without notice. 
* Cypress does not assume any liability arising out of the application or use
* of Software or any product or circuit described in the Software. Cypress does
* not authorize its products for use as critical components in any products 
* where a malfunction or failure may reasonably be expected to result in 
* significant injury or death ("ACTIVE Risk Product"). By including Cypress's 
* product in a ACTIVE Risk Product, the manufacturer of such system or application
* assumes all risk of such use and in doing so indemnifies Cypress against all
* liability. Use of this Software may be limited by and subject to the applicable
* Cypress software license agreement.
*****************************************************************************/
#include "project.h"
#include <stdio.h>

#define MAX_COUNT 65535u

/*******************************************************************************
*        Function Prototypes
*******************************************************************************/
static void HandleError(void);
static void SwInterruptIsr(void);


/*******************************************************************************
*        Global variables
*******************************************************************************/
int count = 0u;
int ucount =0;
uint32_t printCount = false;
uint8_t u8RxStatue=0;
uint8_t u8RxBuf[8];
uint8_t u8RxCnt;
uint8_t u8Crc;

uint32_t read_data;

/*******************************************************************************
* Function Name: SwInterruptIsr
********************************************************************************
* Summary: 
* This function is executed when GPIO interrupt is triggered.
* This ISR 
*        i. Clears the interrupt source.
*        ii. Increments the count and sets printCount flag.
*       
* \Param None
*
* \return
* void
*
*******************************************************************************/
uint8 flag;
static void SwInterruptIsr(void)
{   
    Cy_GPIO_ClearInterrupt(Pin_Switch_0_PORT, Pin_Switch_0_NUM);
      printf("Number of times switch SW5 has been pressed = %d\r\n", count);    
    count++;
    /* If count reaches MAX_COUNT reset the count variable. */
    if(count == MAX_COUNT)
    {
        count = 0u;   
    }
    printCount = true;
    flag=0x55;
	NVIC_ClearPendingIRQ(SysInt_SW_cfg.intrSrc);
}

static void SysInt_UART_Rx_Interrupt(void)
{
   Cy_GPIO_ClearInterrupt(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM);
   //ucount++;
   
}

uint8_t XorCheck(uint8_t *srcData, uint32_t u32Size)
{
    uint8_t *pData=srcData;
    uint8_t u8Xor=0;
    uint32_t uc32Sum=0;
    
    while(u32Size>0)
    {
        uc32Sum+=  *pData;  
        pData++; 
        u32Size--;
    }
    u8Xor=(0xFF ^ ((uint8_t)uc32Sum))+1; 
    return(u8Xor);
}

/*******************************************************************************
* Function Name: main
****************************************************************************//**
*
* Summary:
*  The main function performs the following actions:
*   1. Sets up UART component.
*   2. If initialization of UART component fails then stay in an infinite loop.
*   3. Continuously check whether printCount flag is set.
*   4. If printCount flag is set, reset this flag and print the count using
*      printf function.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main(void)
{
     /* UART initialization status */
    cy_en_scb_uart_status_t uart_status ;
    uint8_t u8RxData;
    
     /* Initialize UART operation. Config and Context structure is copied from Generated source. */
    uart_status  = Cy_SCB_UART_Init(Uart_Printf_HW, &Uart_Printf_config, &Uart_Printf_context);
    if(uart_status != CY_SCB_UART_SUCCESS)
    {
        HandleError();
    }	
    Cy_SCB_UART_Enable(Uart_Printf_HW);
    
    /* Initialize and enable GPIO interrupt assigned to CM4+ */
    /* SysInt_SW_cfg structure is defined in cyfitter_sysint_cfg.c based on
       parameters entered in the Interrupts tab of CYDWR. */
    Cy_SysInt_Init(&SysInt_SW_cfg, SwInterruptIsr); 
    NVIC_ClearPendingIRQ(SysInt_SW_cfg.intrSrc);
    NVIC_EnableIRQ((IRQn_Type)SysInt_SW_cfg.intrSrc);

     __enable_irq(); /* Enable global interrupts. */
    

    for(;;)
    {
  
        u8RxStatue=0;
        #if 1
        while(u8RxStatue==0)   
        {
       
            printCount = false;  

            if((Cy_SCB_GetRxInterruptStatus(Uart_Printf_HW )&0x100)) //0x360
            {
                Uart_Printf_HW->INTR_RX = Uart_Printf_HW->INTR_RX & (SCB_INTR_RX_OVERFLOW_Msk | SCB_INTR_RX_UNDERFLOW_Msk\
                | SCB_INTR_RX_FRAME_ERROR_Msk | SCB_INTR_RX_PARITY_ERROR_Msk);
                
                
                u8RxCnt=0;
              
                
                printf("Found frame error = %d\r\n", count);
            }
            else
            {
                
                if(Cy_SCB_GetNumInRxFifo(Uart_Printf_HW)!=0)
                {
              
                     if (0UL != Cy_SCB_UART_GetNumInRxFifo(Uart_Printf_HW))
                    {
                        /* Re-transmit whatever the user types on the console */
                        u8RxData = Cy_SCB_UART_Get(Uart_Printf_HW);
                           printf("FIFO= %d\r\n",u8RxData);
                       
                    }
                    if(++u8RxCnt==1)
                    {
                         
                        if(0xcc==u8RxData) 
                        {
                            u8RxBuf[0]=0xCC;  
                            
                        }
                        else
                        {
                            
                            u8RxCnt=0;
                        }
                    } 
                    else
                    {
                        u8RxBuf[u8RxCnt-1]=u8RxData;
                        if(u8RxCnt>=8)
                        {
                            u8RxCnt=0;
                            u8Crc=XorCheck(&u8RxBuf[0],7);
                            if(u8RxBuf[7]==u8Crc)
                            {
                                if(u8RxBuf[1]==0x14)
                                {
                                    ucount++;
                                    u8RxStatue=1;
                                  Cy_SCB_UART_ClearRxFifo(Uart_Printf_HW);// 
                                }
                            }
                        }
                    }
                }            
            }
            
        }
        #endif
        #if 1
        CyDelay(1000);
       printf("N=%d\r\n", ucount);       
       
       
         if(flag==0x55)
        {
            
           flag=0;
           printf("entering into deepsleep = %d\r\n", count);
           CyDelay(100);

        Cy_SCB_UART_Disable(Uart_Printf_HW, NULL);
        
        Cy_GPIO_SetDrivemode(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM,  CY_GPIO_DM_HIGHZ );
        Cy_GPIO_SetInterruptEdge(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM, CY_GPIO_INTR_FALLING);
        Cy_GPIO_SetInterruptMask(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM, 1);
        Cy_GPIO_SetVtrip(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM, CY_GPIO_VTRIP_CMOS);

      /* Configure CM4+ CPU GPIO interrupt vector for Port 5 */
        Cy_SysInt_Init(&SysInt_UART_Rx_cfg, SysInt_UART_Rx_Interrupt); 
        NVIC_ClearPendingIRQ(SysInt_UART_Rx_cfg.intrSrc);
        NVIC_EnableIRQ((IRQn_Type)SysInt_UART_Rx_cfg.intrSrc);
   
        Cy_SysPm_DeepSleep(CY_SYSPM_WAIT_FOR_INTERRUPT); 
  
        Cy_GPIO_SetInterruptMask(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM, 0);//intrMask
        Cy_GPIO_SetInterruptEdge(Uart_Printf_rx_0_PORT, Uart_Printf_rx_0_NUM, CY_GPIO_INTR_DISABLE);//intrCfg
        NVIC_DisableIRQ((IRQn_Type)SysInt_UART_Rx_cfg.intrSrc);
       
        Cy_SCB_UART_Enable(Uart_Printf_HW);

        }

        #endif
    }
}





/*******************************************************************************
* Function Name: HandleError
********************************************************************************
* Summary:
* This function processes unrecoverable errors such as UART component 
* initialization error. In case of such error the system will stay in an
* infinite loop of this function.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void HandleError(void)
{
     /* Disable all interrupts */
    __disable_irq();

    while(1u) 
    {
        
    }
}


/*******************************************************************************
* When printf function is called it is redirected to the following functions
* depending on compiler used.
*******************************************************************************/
#if defined (__GNUC__)
/*******************************************************************************
* Function Name: _write
********************************************************************************
* Summary: 
* NewLib C library is used to retarget printf to _write. printf is redirected to 
* this function when GCC compiler is used to print data to terminal using UART. 
*
* \param file
* This variable is not used.
* \param *ptr
* Pointer to the data which will be transfered through UART.
* \param len
* Length of the data to be transfered through UART.
*
* \return
* returns the number of characters transferred using UART.
* \ref int
*******************************************************************************/
    int _write(int file, char *ptr, int len)
    {
        int nChars = 0;

        /* Suppress the compiler warning about an unused variable. */
        if (0 != file)
        {
        }
        
        for (/* Empty */; len != 0; --len)
        {
            /* Block until there is space in the TX FIFO or buffer. */
            while (0UL == Cy_SCB_UART_Put(Uart_Printf_HW, *ptr))
            {
            }
            
            ++nChars;
            ++ptr;
        }
        
        return (nChars);
    }
#elif defined(__ARMCC_VERSION)
    
/*******************************************************************************
* Function Name: fputc
********************************************************************************
* Summary: 
* printf is redirected to this function when MDK compiler is used to print data
* to terminal using UART.
*
* \param ch
* Character to be printed through UART.
*
* \param *file
* pointer to a FILE object that identifies the stream where the character is to be
* written.
*
* \return
* This function returns the character that is written in case of successful
* write operation else in case of error EOF is returned.
* \ref int
*******************************************************************************/
    struct __FILE
    {
        int handle;
    };
    
    enum
    {
        STDIN_HANDLE,
        STDOUT_HANDLE,
        STDERR_HANDLE
    };
    
    FILE __stdin = {STDIN_HANDLE};
    FILE __stdout = {STDOUT_HANDLE};
    FILE __stderr = {STDERR_HANDLE};
    
    int fputc(int ch, FILE *file)
    {
        int ret = EOF;
        switch(file->handle)
        {
            case STDOUT_HANDLE:
                while (0UL == Cy_SCB_UART_Put(Uart_Printf_HW, ch))
                {
                }
                ret = ch;
            break;
                
            case STDERR_HANDLE:
                ret = ch;
            break;
                
            default:
                file = file;
            break;
        }
        return(ret);
    }
    

#endif /* (__GNUC__) */


/* [] END OF FILE */



